==> estateplat-common-1.2.3-20180612.130104-116-sources.jar: cn/gtmap/estateplat/model/server/core/GdYg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过度数据对应预告信息
 * @author lst
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_yg")
public class GdYg implements Serializable {
    @Id
    private String ygid;
    private Double qdjg;
    private String ygdjzmh;
    private String proid;

    private Integer iszx;
    private String bdclx;
    private String ygdjzl;
    private Date gxrq;
    private String djlx;

    private String fj;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    //抵押开始日期
    private Date dyksrq;
    //抵押结束日期
    private Date dyjsrq;

    private Date lzrq;//领证日期
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String zxdaywh;//注销档案业务
    private String daywh;//档案业务
    //增加冗余字段
    private String qlr;//权利人
    private String qlrzjzl;//权利人证件种类
    private String qlrzjh;//权利人证件号
    private String ywr;//义务人
    private String ywrzjzl;//义务人证件种类
    private String ywrzjh;//义务人证件号
    private String ycqzh;//原产权证号
    private String bdcdybh;//不动产单元编号
    private String zl;//坐落

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }
    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }
    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getYgid() {
        return ygid;
    }

    public void setYgid(String ygid) {
        this.ygid = ygid;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getYgdjzmh() {
        return ygdjzmh;
    }

    public void setYgdjzmh(String ygdjzmh) {
        this.ygdjzmh = ygdjzmh;
    }



    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }


    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getDyjsrq() {
        return dyjsrq;
    }

    public void setDyjsrq(Date dyjsrq) {
        this.dyjsrq = dyjsrq;
    }

    public Date getDyksrq() {
        return dyksrq;
    }

    public void setDyksrq(Date dyksrq) {
        this.dyksrq = dyksrq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }
}

==> estateplat-common-1.2.3-20180912.063013-182-sources.jar: cn/gtmap/estateplat/model/server/core/GdYg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过度数据对应预告信息
 * @author lst
 * @version V1.0, 15-4-18
 */
@Table(name = "gd_yg")
public class GdYg implements Serializable {
    @Id
    private String ygid;
    private Double qdjg;
    private String ygdjzmh;
    private String proid;

    private Integer iszx;
    private String bdclx;
    private String ygdjzl;
    private Date gxrq;
    private String djlx;

    private String fj;
    private String cjrid;//创建人ID
    private String yqzh;//原权证号
    //抵押开始日期
    private Date dyksrq;
    //抵押结束日期
    private Date dyjsrq;

    private Date lzrq;//领证日期
    private String bz;//备注
    private Date djsj;//登记时间
    private String dbr;//登薄人
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间
    private String zxywh;//注销业务号
    private String zxdaywh;//注销档案业务
    private String daywh;//档案业务
    //增加冗余字段
    private String qlr;//权利人
    private String qlrzjzl;//权利人证件种类
    private String qlrzjh;//权利人证件号
    private String ywr;//义务人
    private String ywrzjzl;//义务人证件种类
    private String ywrzjh;//义务人证件号
    private String ycqzh;//原产权证号
    private String bdcdybh;//不动产单元编号
    private String zl;//坐落
    private String dyfs;//抵押方式

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }
    public String getDaywh() {
        return daywh;
    }

    public void setDaywh(String daywh) {
        this.daywh = daywh;
    }
    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public String getYqzh() {
        return yqzh;
    }

    public void setYqzh(String yqzh) {
        this.yqzh = yqzh;
    }

    public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public String getYgid() {
        return ygid;
    }

    public void setYgid(String ygid) {
        this.ygid = ygid;
    }

    public Double getQdjg() {
        return qdjg;
    }

    public void setQdjg(Double qdjg) {
        this.qdjg = qdjg;
    }

    public String getYgdjzmh() {
        return ygdjzmh;
    }

    public void setYgdjzmh(String ygdjzmh) {
        this.ygdjzmh = ygdjzmh;
    }



    public Integer getIszx() {
        return iszx;
    }

    public void setIszx(Integer iszx) {
        this.iszx = iszx;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }


    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getYgdjzl() {
        return ygdjzl;
    }

    public void setYgdjzl(String ygdjzl) {
        this.ygdjzl = ygdjzl;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Date getDyjsrq() {
        return dyjsrq;
    }

    public void setDyjsrq(Date dyjsrq) {
        this.dyjsrq = dyjsrq;
    }

    public Date getDyksrq() {
        return dyksrq;
    }

    public void setDyksrq(Date dyksrq) {
        this.dyksrq = dyksrq;
    }

    public Date getLzrq() {
        return lzrq;
    }

    public void setLzrq(Date lzrq) {
        this.lzrq = lzrq;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getZxdaywh() {
        return zxdaywh;
    }

    public void setZxdaywh(String zxdaywh) {
        this.zxdaywh = zxdaywh;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }
}
